@@ -17,7 +17,7 @@ use rustzx_core::{
     zx::constants::{
         CANVAS_HEIGHT, CANVAS_WIDTH, CANVAS_X, CANVAS_Y, FPS, SCREEN_HEIGHT, SCREEN_WIDTH,
     },
-    Emulator, Stopwatch,
+    Emulator,
 };
 use std::{
     fs::{self, File},
@@ -29,38 +29,6 @@ use std::{
 /// max 100 ms interval in `max frames` speed mode
 const MAX_FRAME_TIME: Duration = Duration::from_millis(100);
 
-struct InstantStopwatch {
-    timestamp: Instant,
-}
-
-impl Default for InstantStopwatch {
-    fn default() -> Self {
-        Self {
-            timestamp: Instant::now(),
-        }
-    }
-}
-
-impl Stopwatch for InstantStopwatch {
-    fn reset(&mut self) {
-        self.timestamp = Instant::now();
-    }
-
-    fn measure(&self) -> Duration {
-        self.timestamp.elapsed()
-    }
-}
-
-/// converts nanoseconds  to miliseconds
-fn ns_to_ms(ns: u64) -> f64 {
-    ns as f64 / 1_000_000f64
-}
-
-/// converts miliseconds to nanoseconds
-fn ms_to_ns(s: f64) -> u64 {
-    (s * 1_000_000_f64) as u64
-}
-
 /// returns frame length from given `fps`
 fn frame_length(fps: usize) -> Duration {
     Duration::from_millis((1000_f64 / fps as f64) as u64)
@@ -115,6 +83,11 @@ impl RustzxApp {
                 .load_tape(host::load_tape(tape)?)
                 .map_err(|e| anyhow!("Emulator failed to load tape: {}", e))?;
         }
+        if let Some(screen) = settings.screen.as_ref() {
+            emulator
+                .load_screen(host::load_screen(screen)?)
+                .map_err(|e| anyhow!("Emulator failed to load screen: {}", e))?;
+        }
 
         let file_autodetect = settings.file_autodetect.clone();
 
@@ -156,15 +129,14 @@ impl RustzxApp {
 
     pub fn start(&mut self) -> anyhow::Result<()> {
         let scale = self.scale;
-        let mut stopwatch = InstantStopwatch::default();
         'emulator: loop {
             let frame_target_dt = frame_length(FPS);
             // absolute start time
             let frame_start = Instant::now();
             // Emulate all requested frames
-            let cpu_dt = self
+            let emulator_dt = self
                 .emulator
-                .emulate_frames(MAX_FRAME_TIME, &mut stopwatch)
+                .emulate_frames(MAX_FRAME_TIME)
                 .map_err(|e| anyhow!("Emulation step failed: {}", e))?;
             // if sound enabled sound ganeration allowed then move samples to sound thread
             if let Some(ref mut snd) = self.snd {
@@ -258,8 +230,8 @@ impl RustzxApp {
             // change window header
             if self.enable_frame_trace {
                 log::trace!(
-                    "CPU: {:7.3}ms; FRAME:{:7.3}ms",
-                    cpu_dt.as_millis(),
+                    "EMUALTOR: {:7.3}ms; FRAME:{:7.3}ms",
+                    emulator_dt.as_millis(),
                     frame_dt.as_millis()
                 );
             }
@@ -268,19 +240,23 @@ impl RustzxApp {
     }
 
     fn load_file_autodetect(&mut self, path: &Path) -> anyhow::Result<()> {
-        match host::detect_file_type(&path)? {
+        match host::detect_file_type(path)? {
             DetectedFileKind::Snapshot => {
                 self.emulator
-                    .load_snapshot(host::load_snapshot(&path)?)
+                    .load_snapshot(host::load_snapshot(path)?)
                     .map_err(|e| {
                         anyhow!("Emulator failed to load auto-detected snapshot: {}", e)
                     })?;
             }
             DetectedFileKind::Tape => {
                 self.emulator
-                    .load_tape(host::load_tape(&path)?)
+                    .load_tape(host::load_tape(path)?)
                     .map_err(|e| anyhow!("Emulator failed to load auto-detected tape: {}", e))?;
             }
+            DetectedFileKind::Screen => self
+                .emulator
+                .load_screen(host::load_screen(path)?)
+                .map_err(|e| anyhow!("Emulator failed load screen via auto-detect: {}", e))?,
         }
         Ok(())
     }
