@@ -1,11 +1,11 @@
 use rustzx_core::{
-    error::AssetReadError,
-    host::{LoadableAsset, SeekFrom},
+    error::IoError,
+    host::{DataRecorder, LoadableAsset, SeekFrom, SeekableAsset},
 };
 
 use std::{
     fs::File,
-    io::{Read, Seek},
+    io::{Read, Seek, Write},
 };
 
 pub struct FileAsset {
@@ -18,25 +18,36 @@ impl From<File> for FileAsset {
     }
 }
 
-impl LoadableAsset for FileAsset {
-    fn read(&mut self, buf: &mut [u8]) -> Result<usize, AssetReadError> {
-        self.file.read(buf).map_err(|e| {
-            log::error!("Failed to read asset: {}", e);
-            AssetReadError::HostAssetImplFailed
-        })
-    }
-
-    fn seek(&mut self, pos: SeekFrom) -> Result<usize, AssetReadError> {
+impl SeekableAsset for FileAsset {
+    fn seek(&mut self, pos: SeekFrom) -> Result<usize, IoError> {
         self.file
             .seek(into_std_seek_pos(pos))
             .map_err(|e| {
                 log::error!("Failed to seeek asset: {}", e);
-                AssetReadError::HostAssetImplFailed
+                IoError::HostAssetImplFailed
             })
             .map(|count| count as usize)
     }
 }
 
+impl LoadableAsset for FileAsset {
+    fn read(&mut self, buf: &mut [u8]) -> Result<usize, IoError> {
+        self.file.read(buf).map_err(|e| {
+            log::error!("Failed to read asset: {}", e);
+            IoError::HostAssetImplFailed
+        })
+    }
+}
+
+impl DataRecorder for FileAsset {
+    fn write(&mut self, buf: &[u8]) -> Result<usize, IoError> {
+        self.file.write(buf).map_err(|e| {
+            log::error!("Failed to write data to file: {}", e);
+            IoError::HostAssetImplFailed
+        })
+    }
+}
+
 fn into_std_seek_pos(pos: SeekFrom) -> std::io::SeekFrom {
     match pos {
         SeekFrom::Start(offset) => std::io::SeekFrom::Start(offset as u64),
